#ifndef __MDFN_PSX_INPUT_MOUSE_H
#define __MDFN_PSX_INPUT_MOUSE_H

namespace MDFN_IEN_PSX
{

InputDevice *Device_Mouse_Create(void);
extern IDIISG Device_Mouse_IDII;

}
#endif
